# Changelog

## [1.2.4a1](https://github.com/OpenVoiceOS/ovos-core/tree/1.2.4a1) (2025-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/1.2.3...1.2.4a1)

**Merged pull requests:**

- optimizing German translation for better usage [\#671](https://github.com/OpenVoiceOS/ovos-core/pull/671) ([gitlocalize-app[bot]](https://github.com/apps/gitlocalize-app))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
